=============
 Nitime news
=============

November 6 2025: Version 0.12 released.

June 17 2024: Version 0.11 released.

October 31 2023: Version 0.10.2 released.

April 4 2023: Version 0.10.1 released.

April 4 2023: Version 0.10 released.

December 19 2020: Version 0.9 releassed

June 25 2019: Version 0.8.1 released.

June 22 2019: Version 0.8 released.

December 15, 2016: Version 0.7 released.

February 7 2016: Version 0.6 released.

June 13 2014: Version 0.5 released.

June 19 2012: Version 0.4 released.

August 13 2011: Version 0.3 released. 

November 9 2010: Version 0.2 released. 

August 18 2010: Nitime version 0.1 is officially out.

Scipy 2009 conference paper `available <_static/Scipy2009Nitime.pdf>`_
